#!/usr/bin/perl -w
#
# tests/ldap-group-maint.t

use Test::More qw( no_plan );

my $s = '../usr/bin/ldap-group-maint';

# Create a ticket file for the conf file to find
my $tfile = 'ldap-sync-attribute.keytab';
open $OUT, ">$tfile";
close $OUT;

# All of the configuration file properties are specified
# to make sure we haven't misspelled something in the
# script.  With a config file we can test both forms
# of help
my $cfile = 'ldap-group-maint.conf';
my $OUT;
open $OUT, ">$cfile";
print $OUT "ldap_host = host.domain\n";
print $OUT "debug = 0\n";
print $OUT "group_base_dn = cn=groups,dc=Stanford,dc=edu\n";
print $OUT "people_base_dn = cn=people,dc=Stanford,dc=edu\n";
print $OUT "mail_domain = \@stanford.edu\n";
print $OUT "maildrop_domain = \@googlegroup.stanford.edu\n";
print $OUT "addtype = posixGroup,google\n";
print $OUT "generate_gid\n";
print $OUT "gidnumber_minimum = 100000\n";
print $OUT "gidnumber_loop_maximum = 50000\n";
print $OUT "keytab_file = $tfile\n";
print $OUT "principal_name = service/some-service\n";
print $OUT "tgt_file = /tmp/krb5.tgt\n";
close $OUT;

my $t1 = `$s help --config=$cfile 2>&1`;
ok ($t1 =~ /^Usage/, 'Help command line argument');
print "$t1\n" if $t1 !~ /^Usage/;

my $t2 = `$s --help 2>&1`;
ok ($t2 =~ /^Usage/, 'Help switch');
print "$t2\n" if $t2 !~ /^Usage/;

unlink $cfile if -e $cfile;
unlink $tfile if -e $tfile;

my $t = "${s}.tdy";

my @cmd = ('perltidy');
push @cmd, '-bbao';  # put line breaks before any operator
push @cmd, '-nbbc';  # don't force blank lines before comments
push @cmd, '-ce';    # cuddle braces around else
push @cmd, '-l=79';  # usually use 78, but don't want 79-long lines reformatted
push @cmd, '-pt=2';  # don't add extra whitespace around parentheses
push @cmd, '-sbt=2'; # ...or square brackets
push @cmd, '-sfs';   # no space before semicolon in for
push @cmd, $s;
system(@cmd);

@cmd = ('diff', '-u', $s, $t);
system(@cmd) == 0
    or die "$s is UNTIDY\n";

ok ('success', 'Tidy');
unlink $t;
